ExtractedMetadata class

Metadata extracted from inline Allure annotations in text.

Constructors

ExtractedMetadata({required String cleanName, String? allureId, String? displayName, List<AllureLabel> labels = const <AllureLabel>[], List<AllureLink> links = const <AllureLink>[]})
Creates extracted metadata.
const

Properties

allureId → String?
Parsed Allure id, when present.
final
cleanName → String
Text with Allure annotations removed.
final
displayName → String?
Parsed display name override, when present.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → List<AllureLabel>
Parsed Allure labels.
final
Parsed Allure links.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited