ExtractedMetadata class

Constructors

ExtractedMetadata({required String cleanName, String? allureId, String? displayName, List<AllureLabel> labels = const <AllureLabel>[], List<AllureLink> links = const <AllureLink>[]})
const

Properties

allureId String?
final
cleanName String
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
labels List<AllureLabel>
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited