PackageTestMetadata class
Constructors
-
PackageTestMetadata({required String name, required String fullName, required String testCaseName, required List<
String> titlePath, required List<String> groupPath, required String? packagePath, required List<AllureLabel> labels, required List<AllureLink> links, required List<AllureParameter> parameters, required String? externalId, required String? nativeSelector, required List<String> rawTags, required bool skipped}) -
const
Properties
- externalId → String?
-
final
- fullName → String
-
final
-
groupPath
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ List<
AllureLabel> -
final
-
links
→ List<
AllureLink> -
final
- name → String
-
final
- nativeSelector → String?
-
final
- packagePath → String?
-
final
-
parameters
→ List<
AllureParameter> -
final
-
rawTags
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipped → bool
-
final
- testCaseName → String
-
final
- testClass → String
-
no setter
-
titlePath
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited