PackageTestScopeRegistry class
Registry of declared package:test scopes and metadata.
Properties
- currentPackagePath → String?
-
Current package-relative test file path, when known.
no setter
-
currentPath
→ List<
String> -
Current declaration-time group path.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
expectedChildrenForPath(
List< String> path, {required String? packagePath}) → int? -
Returns the expected child count for a group
path. -
metadataForFullName(
String fullName) → PackageTestMetadata? -
Returns declaration-time metadata for
fullName, when present. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popGroup(
) → void - Pops the latest group from the declaration stack.
-
pushGroup(
String name, {required String? packagePath}) → void - Pushes a group onto the declaration stack.
-
registerMetadata(
PackageTestMetadata metadata) → void - Stores declaration-time metadata for a test.
-
registerTest(
{required String? packagePath}) → void - Registers a declared test for scope child counts.
-
scopeIdForPath(
List< String> path, {required String? packagePath}) → String -
Returns the scope id for a group
path. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PackageTestScopeRegistry
-
Singleton registry used by the drop-in test wrappers.
final