PackageTestScopeRegistry class
Properties
- currentPackagePath → String?
-
no setter
-
currentPath
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
expectedChildrenForPath(
List< String> path, {required String? packagePath}) → int? -
metadataForFullName(
String fullName) → PackageTestMetadata? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popGroup(
) → void -
pushGroup(
String name, {required String? packagePath}) → void -
registerMetadata(
PackageTestMetadata metadata) → void -
registerTest(
{required String? packagePath}) → void -
scopeIdForPath(
List< String> path, {required String? packagePath}) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PackageTestScopeRegistry
-
final