PreparedPackageTestDeclaration class
Shared skip / test-plan resolution for package:test-style drop-ins.
Constructors
- PreparedPackageTestDeclaration({required PackageTestMetadata metadata, required bool excludedByTestPlan, required bool shouldRuntimeSkip, required String runtimeSkipReason})
-
Creates a prepared declaration.
const
Properties
- declarationSkip → Object?
-
Declaration-time skip value for APIs that accept
Object? skip.no setter - declarationSkipFlag → bool?
-
Declaration-time skip flag for APIs that accept
bool? skip.no setter - excludedByTestPlan → bool
-
Whether the test is excluded by the active Allure test plan.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → PackageTestMetadata
-
Declared Allure metadata registered for this test.
final
- runtimeSkipReason → String
-
Reason passed to
markTestSkippedwhen shouldRuntimeSkip is true.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldRuntimeSkip → bool
-
Whether the body should self-skip via
markTestSkippedat runtime.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited